*****************************
glowing-waffles Documentation
*****************************

This is the documentation for glowing-waffles.

Reference/API
=============

.. automodapi:: glowing_waffles
.. automodapi:: glowing_waffles.differential_photometry
.. automodapi:: glowing_waffles.visualization
.. automodapi:: glowing_waffles.io
